Crate recall_actor_sdk

Crate recall_actor_sdk 

Macros

declare_abi_call

Structs

InputData
EVM call with selector (first 4 bytes) and calldata (remaining bytes)
InvokeContractParams
InvokeContractReturn

Traits

TryIntoEVMEvent

Functions

emit_evm_event
Emits an ActorEvent from an EVM event.
hash_rm
require_addr_is_origin_or_caller
Returns an error if the address does not match the message origin or caller.
to_actor_event
Returns an ActorEvent from an EVM event.
to_delegated_address
Resolves an address to its external delegated address.
to_id_address
Resolves ID address of an actor. If require_delegated is true, the address must be of type EVM (a Solidity contract), EthAccount (an Ethereum-style EOA), or Placeholder (a yet to be determined EOA or Solidity contract).
to_id_and_delegated_address
Resolves an address to its ID address and external delegated address.
token_to_biguint
Returns the TokenAmount as a BigUint. If the given amount is negative, the value returned will be zero.