Macros
Structs
- Input
Data - EVM call with selector (first 4 bytes) and calldata (remaining bytes)
- Invoke
Contract Params - Invoke
Contract Return
Traits
Functions
- emit_
evm_ event - Emits an
ActorEventfrom an EVM event. - hash_rm
- require_
addr_ is_ origin_ or_ caller - Returns an error if the address does not match the message origin or caller.
- to_
actor_ event - Returns an
ActorEventfrom an EVM event. - to_
delegated_ address - Resolves an address to its external delegated address.
- to_
id_ address - Resolves ID address of an actor.
If
require_delegatedistrue, the address must be of type EVM (a Solidity contract), EthAccount (an Ethereum-style EOA), or Placeholder (a yet to be determined EOA or Solidity contract). - to_
id_ and_ delegated_ address - Resolves an address to its ID address and external delegated address.
- token_
to_ biguint - Returns the
TokenAmountas aBigUint. If the given amount is negative, the value returned will be zero.